@@ -12,6 +12,11 @@ var collectObjectOperatorScenarios = []expressionScenario{
 			"D0, P[name], (!!str)::mike\n",
 		},
 	},
+	{
+		skipDoc:       true,
+		expression:    `{"c": "a", "b", "d"}`,
+		expectedError: "CollectObject: mismatching node sizes; are you creating a map with mismatching key value pairs?",
+	},
 	{
 		skipDoc:    true,
 		expression: `{"person": {"names": ["mike"]}} | .person.names[0]`,
@@ -28,6 +33,16 @@ var collectObjectOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::dog: great\n",
 		},
 	},
+	{
+		description: "collect splat",
+		skipDoc:     true,
+		document:    `[{name: cat}, {name: dog}]`,
+		expression:  `.[] | {.name: "great"}[]`,
+		expected: []string{
+			"D0, P[cat], (!!str)::great\n",
+			"D0, P[dog], (!!str)::great\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		expression: `({} + {}) | (.b = 3)`,
