@@ -18,7 +18,7 @@ var hasOperatorScenarios = []expressionScenario{
 		document:   `a: hello`,
 		expression: `has(.b) as $c | .`,
 		expected: []string{
-			"D0, P[], (doc)::a: hello\n",
+			"D0, P[], (!!map)::a: hello\n",
 		},
 	},
 	{
