@@ -18,7 +18,7 @@ var pipeOperatorScenarios = []expressionScenario{
 		document:    `{a: cow, b: sheep, c: same}`,
 		expression:  `.a = "cat" | .b = "dog"`,
 		expected: []string{
-			"D0, P[], (doc)::{a: cat, b: dog, c: same}\n",
+			"D0, P[], (!!map)::{a: cat, b: dog, c: same}\n",
 		},
 	},
 	{
