@@ -14,6 +14,16 @@ var uniqueOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::[2, 1, 3]\n",
 		},
 	},
+	{
+		description: "Unique splat",
+		skipDoc:     true,
+		document:    `[2,1,2]`,
+		expression:  `unique[]`,
+		expected: []string{
+			"D0, P[0], (!!int)::2\n",
+			"D0, P[1], (!!int)::1\n",
+		},
+	},
 	{
 		description:    "Unique nulls",
 		subdescription: "Unique works on the node value, so it considers different representations of nulls to be different",
@@ -33,13 +43,29 @@ var uniqueOperatorScenarios = []expressionScenario{
 		},
 	},
 	{
-		description: "Unique array object fields",
+		description: "Unique array objects",
+		document:    `[{name: harry, pet: cat}, {name: billy, pet: dog}, {name: harry, pet: cat}]`,
+		expression:  `unique`,
+		expected: []string{
+			"D0, P[], (!!seq)::[{name: harry, pet: cat}, {name: billy, pet: dog}]\n",
+		},
+	},
+	{
+		description: "Unique array of objects by a field",
 		document:    `[{name: harry, pet: cat}, {name: billy, pet: dog}, {name: harry, pet: dog}]`,
 		expression:  `unique_by(.name)`,
 		expected: []string{
 			"D0, P[], (!!seq)::[{name: harry, pet: cat}, {name: billy, pet: dog}]\n",
 		},
 	},
+	{
+		description: "Unique array of arrays",
+		document:    `[[cat,dog], [cat, sheep], [cat,dog]]`,
+		expression:  `unique`,
+		expected: []string{
+			"D0, P[], (!!seq)::[[cat, dog], [cat, sheep]]\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `[{name: harry, pet: cat}, {pet: fish}, {name: harry, pet: dog}]`,
@@ -48,6 +74,16 @@ var uniqueOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::[{name: harry, pet: cat}, {pet: fish}]\n",
 		},
 	},
+	{
+		description: "unique by splat",
+		skipDoc:     true,
+		document:    `[{name: harry, pet: cat}, {pet: fish}, {name: harry, pet: dog}]`,
+		expression:  `unique_by(.name)[]`,
+		expected: []string{
+			"D0, P[0], (!!map)::{name: harry, pet: cat}\n",
+			"D0, P[1], (!!map)::{pet: fish}\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `[{name: harry, pet: cat}, {pet: fish}, {name: harry, pet: dog}]`,
@@ -63,6 +99,7 @@ var uniqueOperatorScenarios = []expressionScenario{
 		expected: []string{
 			"D0, P[], (!!seq)::# abc\n[{name: harry, pet: cat}, {pet: fish}]\n# xyz\n",
 		},
+		skipForGoccy: true, // https://github.com/goccy/go-yaml/issues/757
 	},
 }
 
