@@ -7,16 +7,18 @@ type YamlPreferences struct {
 	PrintDocSeparators          bool
 	UnwrapScalar                bool
 	EvaluateTogether            bool
+	FixMergeAnchorToSpec        bool
 }
 
 func NewDefaultYamlPreferences() YamlPreferences {
 	return YamlPreferences{
 		Indent:                      2,
-		ColorsEnabled:               true,
+		ColorsEnabled:               false,
 		LeadingContentPreProcessing: true,
 		PrintDocSeparators:          true,
 		UnwrapScalar:                true,
 		EvaluateTogether:            false,
+		FixMergeAnchorToSpec:        false,
 	}
 }
 
@@ -28,6 +30,7 @@ func (p *YamlPreferences) Copy() YamlPreferences {
 		PrintDocSeparators:          p.PrintDocSeparators,
 		UnwrapScalar:                p.UnwrapScalar,
 		EvaluateTogether:            p.EvaluateTogether,
+		FixMergeAnchorToSpec:        p.FixMergeAnchorToSpec,
 	}
 }
 
